@@ -1,5 +1,5 @@
 /*******************************************************************************
-* Copyright 2020-2021 Intel Corporation
+* Copyright 2020 Intel Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
@@ -139,6 +139,7 @@ public:
     MSG(vertex_index_out_of_range_expect_from_zero_to_vertex_count);
     MSG(negative_vertex_id);
     MSG(unimplemented_sorting_procedure);
+    MSG(edge_values_are_empty);
 
     /* I/O */
     MSG(file_not_found);
@@ -292,6 +293,7 @@ public:
     MSG(invalid_mpi_comm);
     MSG(invalid_root);
     MSG(unknown_mpi_error);
+    MSG(sendrecv_replace_is_not_implemented_for_threaded_communicator);
 };
 
 #undef MSG
