@@ -1,5 +1,5 @@
 /*******************************************************************************
-* Copyright 2020-2021 Intel Corporation
+* Copyright 2020 Intel Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
@@ -103,7 +103,7 @@ template <typename Alloc>
 struct alloc_connector : public byte_alloc_iface {
     using allocator_traits_t =
         typename std::allocator_traits<Alloc>::template rebind_traits<byte_t>;
-    using t_byte_allocator = typename std::allocator_traits<Alloc>::template rebind_alloc<byte_t>;
+    using byte_allocator_t = typename std::allocator_traits<Alloc>::template rebind_alloc<byte_t>;
     alloc_connector(Alloc alloc) : alloc_(alloc) {}
     byte_t* allocate(std::int64_t count) override {
         auto ptr = allocator_traits_t::allocate(alloc_, count);
@@ -120,7 +120,33 @@ struct alloc_connector : public byte_alloc_iface {
     };
 
 private:
-    t_byte_allocator alloc_;
+    byte_allocator_t alloc_;
+};
+
+template <typename Allocator>
+struct rebinded_allocator {
+    explicit rebinded_allocator(Allocator allocator) : allocator_(allocator) {}
+
+    template <typename Array>
+    std::tuple<Array, typename Array::data_t*> allocate_array(std::int64_t count) {
+        using data_t = typename Array::data_t;
+        using data_allocator_t =
+            typename std::allocator_traits<Allocator>::template rebind_alloc<data_t>;
+
+        data_allocator_t data_allocator(allocator_);
+        data_t* array_values = oneapi::dal::preview::detail::allocate(data_allocator, count);
+
+        Array array(
+            array_values,
+            count,
+            oneapi::dal::preview::detail::destroy_delete<data_t, data_allocator_t>(count,
+                                                                                   data_allocator));
+
+        return { array, array.get_mutable_data() };
+    }
+
+private:
+    Allocator allocator_;
 };
 
 } // namespace oneapi::dal::preview::detail
