@@ -84,6 +84,11 @@ public:
                                      std::int64_t count,
                                      const data_type& dtype,
                                      const reduce_op& op) = 0;
+    virtual request_iface* sendrecv_replace(byte_t* buf,
+                                            std::int64_t count,
+                                            const data_type& dtype,
+                                            std::int64_t destination_rank,
+                                            std::int64_t source_rank) = 0;
 };
 
 template <typename MemoryAccessKind>
@@ -102,6 +107,7 @@ public:
     using base_t::bcast;
     using base_t::allgatherv;
     using base_t::allreduce;
+    using base_t::sendrecv_replace;
 
     virtual request_iface* bcast(sycl::queue& q,
                                  byte_t* send_buf,
@@ -124,6 +130,13 @@ public:
                                      const data_type& dtype,
                                      const reduce_op& op,
                                      const std::vector<sycl::event>& deps) = 0;
+    virtual request_iface* sendrecv_replace(sycl::queue& q,
+                                            byte_t* buf,
+                                            std::int64_t count,
+                                            const data_type& dtype,
+                                            std::int64_t destination_rank,
+                                            std::int64_t source_rank,
+                                            const std::vector<sycl::event>& deps) = 0;
     virtual sycl::queue get_queue() = 0;
 };
 
@@ -413,8 +426,75 @@ public:
     }
     template <typename D>
     request allreduce(const array<D>& ary, const reduce_op& op = reduce_op::sum) const;
+    /// Shuffles data reusing the same buffer for send and receive operations
+    ///
+    /// @param buf                  The buffer
+    /// @param count                The number of elements of `dtype` sent to and
+    ///                             received from for each rank
+    /// @param dtype                The type of elements in the passed buffers
+    /// @param destination_rank     The rank to send data to.
+    /// @param source_rank          The rank to receive data from.
+    ///
+    /// @return The object to track the progress of the operation
+    request sendrecv_replace(byte_t* buf,
+                             std::int64_t count,
+                             const data_type& dtype,
+                             std::int64_t destination_rank,
+                             std::int64_t source_rank) const {
+        wait_for_exception_handling();
+        return dal::detail::make_private<request>(
+            impl_->sendrecv_replace(buf, count, dtype, destination_rank, source_rank));
+    }
+#ifdef ONEDAL_DATA_PARALLEL
+    /// `sendrecv_replace` that accepts USM pointers
+    request sendrecv_replace(sycl::queue& q,
+                             byte_t* buf,
+                             std::int64_t count,
+                             const data_type& dtype,
+                             std::int64_t destination_rank,
+                             std::int64_t source_rank,
+                             const std::vector<sycl::event>& deps = {}) const {
+        wait_for_exception_handling();
+        return dal::detail::make_private<request>(
+            impl_->sendrecv_replace(q, buf, count, dtype, destination_rank, source_rank, deps));
+    }
+#endif
+    template <typename D, enable_if_primitive_t<D>* = nullptr>
+    request sendrecv_replace(D* buf,
+                             std::int64_t count,
+                             std::int64_t destination_rank,
+                             std::int64_t source_rank) const {
+        return sendrecv_replace(reinterpret_cast<byte_t*>(buf),
+                                count,
+                                dal::detail::make_data_type<D>(),
+                                destination_rank,
+                                source_rank);
+    }
+#ifdef ONEDAL_DATA_PARALLEL
+    template <typename D,
+              typename T = MemoryAccessKind,
+              typename = std::enable_if_t<dal::detail::is_one_of_v<T, device_memory_access::usm> &&
+                                          is_primitive_v<D>>>
+    request sendrecv_replace(sycl::queue& queue,
+                             D* buf,
+                             std::int64_t count,
+                             std::int64_t destination_rank,
+                             std::int64_t source_rank,
+                             const std::vector<sycl::event>& deps = {}) const {
+        return sendrecv_replace(queue,
+                                reinterpret_cast<byte_t*>(buf),
+                                count,
+                                dal::detail::make_data_type<D>(),
+                                destination_rank,
+                                source_rank,
+                                deps);
+    }
+#endif
+    template <typename D>
+    request sendrecv_replace(const array<D>& buf,
+                             std::int64_t destination_rank,
+                             std::int64_t source_rank) const;
 #ifdef ONEDAL_DATA_PARALLEL
-    /// `bcast` that accepts USM pointers
     template <typename T = MemoryAccessKind, typename = enable_if_device_memory_accessible_t<T>>
     sycl::queue get_queue() const {
         return impl_->get_queue();
